/*
 * Project: Examples for GJA course
 * Authors: Ing. Jan Kouřil
 *          Ing. Jaroslav Dytrych idytrych@fit.vutbr.cz
 * File: Tester.java
 * Description: Example Jersey application for CRUD - testing client
 */

/**
 * @file Tester.java
 *
 * @brief Example Jersey application for CRUD - testing client
 */

/**
 * @package cz.vutbr.fit.knot.gja.CRUD.client
 * 
 * @brief Example Jersey application for CRUD - testing client
 */
package cz.vutbr.fit.knot.gja.CRUD.client;

import java.net.URI;

import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.UriBuilder;

import cz.vutbr.fit.knot.gja.CRUD.shared.Todo;
import javax.ws.rs.client.Client;
import javax.ws.rs.client.ClientBuilder;
import javax.ws.rs.client.Entity;
import javax.ws.rs.client.WebTarget;
import javax.ws.rs.core.Form;
import javax.ws.rs.core.Response;

/**
 * Example Jersey application for CRUD - testing client
 */
public class Tester {
  
  /**
   * Main method
   * 
   * @param args Command line arguments 
   */
  public static void main(String[] args) {
    Client client = ClientBuilder.newBuilder().build();
    
    // Create one todo
    Todo todo = new Todo("3", "Blablabla");
    
    WebTarget target = client.target(getBaseURI()).path("rest").path("todos");
    
    Response response = target.path(todo.getId()).request(MediaType.APPLICATION_XML).put(Entity.xml(todo));
    // Return code should be 204 No Content => created resource
    System.out.println(response.getStatus());
    
    // Get the Todos
    System.out.println(target.path(todo.getId()).request(MediaType.TEXT_XML).get(String.class));
    
    // Get JSON for application
    // In GlassFish 4.1.1 fails https://github.com/IQSS/dataverse/issues/2628
    // Read:
    // https://stackoverflow.com/questions/33722764/glassfish-error-when-producing-json
    // https://stackoverflow.com/questions/31275480/glassfish-4-rest-xml-working-json-error
    // Fix: In glassfish-4.1.1/glassfish/modules/ replace jackson-annotations.jar, 
    // jackson-core.jar, jackson-databind.jar, jackson-jaxrs-base.jar, 
    // jackson-jaxrs-json-provider.jar and jackson-module-jaxb-annotations.jar 
    // with newer versions from Maven repository (tested with 2.9.1). 
    // In glassfish-4.1.1/glassfish/modules/ replace org.eclipse.persistence.antlr.jar, 
    // org.eclipse.persistence.asm.jar, org.eclipse.persistence.core.jar, 
    // org.eclipse.persistence.dbws.jar, org.eclipse.persistence.jpa.jpql.jar, 
    // org.eclipse.persistence.jpa.modelgen.processor.jar, org.eclipse.persistence.jpa.jar, 
    // org.eclipse.persistence.moxy.jar and  org.eclipse.persistence.oracle.jar 
    // with newer versions from Maven repository (tested with 2.7.0). 
    // Delete directory glassfish-4.1.1/glassfish/domains/domain1/osgi-cache/felix
    System.out.println(target.request(MediaType.APPLICATION_JSON).get(String.class));
    
    // Get XML for application
    System.out.println(target.path(todo.getId()).request(MediaType.APPLICATION_XML).get(String.class));

    // Get the Todo with id 1
    System.out.println(target.path("1").request(MediaType.APPLICATION_XML).get(String.class));
    // Delete Todo with id 1
    target.path("1").request().delete();
    // Get the all todos, id 1 should be deleted
    System.out.println(target.request(MediaType.APPLICATION_XML).get(String.class));

    // create a Todo
    Form form = new Form();
    form.param("id", "4");
    form.param("summary", "Demonstration of the client lib for forms");
    response = target.request().post(Entity.form(form));
    System.out.println("Form response " + response.getEntity());
    // Get the all todos, id 4 should be created
    System.out.println(target.request(MediaType.APPLICATION_XML).get(String.class));

  }  // main()

  /**
   * Gets server base URI
   * 
   * @return Returns server base URI
   */
  private static URI getBaseURI() {
    return UriBuilder.fromUri("http://localhost:8080/JerseyCRUD").build();
  }
} // public class Tester
