/*
 * Project: Examples for GJA course
 * Authors: Ing. Jan Kouřil
 *          Ing. Jaroslav Dytrych idytrych@fit.vutbr.cz
 * File: JerseyClientGet.java
 * Description: Example Jersey application with using JSON - client using GET
 *
 * In GlassFish 4.1.1 it will fail https://github.com/IQSS/dataverse/issues/2628
 * Read:
 * https://stackoverflow.com/questions/33722764/glassfish-error-when-producing-json
 * https://stackoverflow.com/questions/31275480/glassfish-4-rest-xml-working-json-error
 * Fix: 
 * In glassfish-4.1.1/glassfish/modules/ replace jackson-annotations.jar, 
 * jackson-core.jar, jackson-databind.jar, jackson-jaxrs-base.jar, 
 * jackson-jaxrs-json-provider.jar and jackson-module-jaxb-annotations.jar 
 * with newer versions from Maven repository (tested with 2.9.1). 
 * In glassfish-4.1.1/glassfish/modules/ replace org.eclipse.persistence.antlr.jar, 
 * org.eclipse.persistence.asm.jar, org.eclipse.persistence.core.jar, 
 * org.eclipse.persistence.dbws.jar, org.eclipse.persistence.jpa.jpql.jar, 
 * org.eclipse.persistence.jpa.modelgen.processor.jar, org.eclipse.persistence.jpa.jar, 
 * org.eclipse.persistence.moxy.jar and  org.eclipse.persistence.oracle.jar 
 * with newer versions from Maven repository (tested with 2.7.0). 
 * Delete directory glassfish-4.1.1/glassfish/domains/domain1/osgi-cache/felix
 */

/**
 * @file JerseyClientGet.java
 *
 * @brief Example Jersey application with using JSON - client using GET
 */

/**
 * @package cz.vutbr.fit.knot.gja.JJB.client
 * 
 * @brief Example Jersey application with using JSON - client using GET
 */
package cz.vutbr.fit.knot.gja.JJ.client;

import java.net.URI;
import javax.ws.rs.client.Client;
import javax.ws.rs.client.ClientBuilder;
import javax.ws.rs.client.WebTarget;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.UriBuilder;

/**
 * Example Jersey application with using JSON - client using GET
 */
public class JerseyClientGet {

  /**
   * Main method
   * 
   * @param args Command line arguments
   */
  public static void main(String[] args) {

    Client client = ClientBuilder.newBuilder().build();
    WebTarget target = client.target(getBaseURI()).path("rest").path("json")
                       .path("metallica").path("get");
      

    Response response = target.request(MediaType.APPLICATION_JSON).get();

    if (response.getStatus() != 200) {
      throw new RuntimeException("Failed : HTTP error code : "
                                 + response.getStatus());
    }

    String output = response.readEntity(String.class);

    System.out.println("Output from Server .... \n");
    System.out.println(output);
  }
  
  /**
   * Gets server base URI
   * 
   * @return Returns server base URI
   */
  private static URI getBaseURI() {
    return UriBuilder.fromUri("http://localhost:8080/JerseyJSON").build();
  }
}